@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::LiveJournal;
 {
-  $WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1703';
+  $WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1704';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::LiveJournal - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1703
+version 0.1704
 
 =head1 DESCRIPTION
 
@@ -110,6 +110,10 @@ sub extract_story {
 	$ljuser= $1;
 	$title = $2;
     }
+    elsif ($content =~ m#<h1 class="b-singlepost-title">\s*([^<]+)\s*</h1>#s)
+    {
+	$title = $1;
+    }
     elsif ($content =~ m#<h2 class="asset-name page-header2"><a href="([^"]+)">([^>]+)</a></h2>#)
     {
 	$url = $1;
@@ -164,6 +168,10 @@ sub extract_story {
     {
 	$story = $1;
     }
+    elsif ($content =~ m#<div class="b-singlepost-body">(.*?)<div class="b-singlepost-tags ljtags">#s)
+    {
+	$story = $1;
+    }
     elsif ($content =~ m#<div class="entrytext">(.*?)<div class="meta">#s)
     {
 	$story = $1;
